pub mod title;
pub mod tray;
pub mod sensors;
pub mod bspwm;
pub mod spacer;
pub mod music;

use xcb;
use mpd;
use std::sync::mpsc;

pub type MessageSender = mpsc::Sender<Message>;

pub enum Message {
    Relayout,
    Update,
    Quit,
    MousePress(u16),
    BspwmEvent(String),
    MpdEvent(mpd::status::State, String, String),
    XcbEvent(xcb::GenericEvent)
}

pub trait Widget {
    fn init(&mut self) {}
    fn render(&mut self, x: u16);
    fn width(&mut self) -> u16;
    fn handle_event(&mut self, _event: &Message) -> bool {
        false
    }
    fn finish(&mut self) {}
}
